"""
HumData - A Humanitarian Data Analytics Helper Library
"""

from .csv import open_csv
from .excel import open_excel
from .json import open_json
from .xml import open_xml
from .postgres import open_postgres
from .mysql import open_mysql
from .API import open_api
from .geojson import open_geojson
from .parquet import open_parquet
from .spss import open_spss
from .netcdf import open_netcdf

__all__ = [
    "open_csv",
    "open_excel",
    "open_json",
    "open_xml",
    "open_sqlite",
    "open_postgres",
    "open_mysql",
    "open_api",
    "open_geojson",
    "open_parquet",
    "open_spss",
    "open_netcdf"
]
