"""HuDa — Humanitarian Data Library

Convenience namespace for humanitarian data utilities.
"""

__all__ = [
    "opening",
    "cleaning",
    "transformation",
    "validation_and_quality",
    "geospatial",
    "analysis",
    "visualize",
    "automation",
    "document_processing",
    "humanitarian_metrics",
    "ml4humanitarian",
    "Interoperability",
]

__version__ = "0.1.3"
